==> scripture_phaser-1.0.0.tar.gz: scripture_phaser-1.0.0/README.md <==
# Scripture Phaser

scripture_phaser helps you to memorize the Bible.

![scripture_phaser Demo](demo.gif)

## Installation

This package is available through PIP:

pip install scripture_phaser

## Usage

scripture_phaser [-h] [--version] [--license]

Running scripture_phaser with no arguments launches the interactive CLI.

### Commands

From the interactive CLI, the following commands are available:

* g/get         - Reload the configuration file
* w/write       - Save the current configuration
* l/list        - Lists selected reference, mode and translation
* m/mode        - Toggles the mode
* r/reference   - Sets the reference
* t/translation - Set the translation
* i/inquire     - List available translations
* p/practice    - Practice the current reference
* v/view        - Preview current reference
* s/stats       - View your statistics
* h/help        - Prints this help message
* z/reset       - Reset statistics
* q/quit        - Quits scripture_phaser

## Uninstallation

pip uninstall scripture_phaser

## What's up with the Name?

Why is this tool called "scripture_phaser"? The name is actually a reference to a fictional weapon that appeared in an episode on of Focus on the Family's radio drama "Adventures in Odyssey" back in 1995 called "Hidden in My Heart".

In one particular segment of the show, the characters are parodying an away mission from the original "Star Trek" series with William Shatner. Sky Trip's own captain, played by William Shattered, along with his trusty sidekick Krok and one expendable crewman beam down to an alien world to rescue a damsel in distress. Among the other trinkets that they take with them are their scripture phasers. These devices thwart attempts to tempt the trio to sin by citing relevant pieces of scripture. The entire segment is very tongue-in-cheek, but absolutely entertaining.

The entire episode was released for free by Focus on the Family as a part of an episode of "The Official Adventures in Odyssey Podcast".

[Link to The Podcast Episode](https://www.oneplace.com/ministries/the-official-adventures-in-odyssey-podcast/player/june-13-2007-free-adventures-in-odyssey-episode-hidden-in-my-heart-798810.html)

The "Sky Trip" portion of the episode starts at 12:28, if you want to skip directly to it.

## License

scripture_phaser is licensed under the BSD 3-Clause License. See LICENSE file or the [Open Source Initiative](https://opensource.org/license/bsd-3-clause/) for the full text of the license.

==> scripture_phaser-1.0.2.tar.gz: scripture_phaser-1.0.2/README.md <==
# Scripture Phaser

scripture_phaser helps you to memorize the Bible.

![scripture_phaser Demo](demo.gif)

## Installation

This package is available through PIP:

pip install scripture_phaser

## Usage

scripture_phaser [-h] [--version] [--license]

Running scripture_phaser with no arguments launches the interactive CLI.

### Commands

From the interactive CLI, the following commands are available:

* g/get         - Reload the configuration file
* w/write       - Save the current configuration
* l/list        - Lists selected reference, random mode and translation
* m/random_mode - Toggles the mode
* r/reference   - Sets the reference
* t/translation - Set the translation
* i/inquire     - List available translations
* p/practice    - Practice the current reference
* v/view        - Preview current reference
* s/stats       - View your statistics
* h/help        - Prints this help message
* z/reset       - Reset statistics
* q/quit        - Quits scripture_phaser

## Uninstallation

pip uninstall scripture_phaser

## What's up with the Name?

Why is this tool called "scripture_phaser"? The name is actually a reference to a fictional weapon that appeared in an episode on of Focus on the Family's radio drama "Adventures in Odyssey" back in 1995 called "Hidden in My Heart".

In one particular segment of the show, the characters are parodying an away mission from the original "Star Trek" series with William Shatner. Sky Trip's own captain, played by William Shattered, along with his trusty sidekick Krok and one expendable crewman beam down to an alien world to rescue a damsel in distress. Among the other trinkets that they take with them are their scripture phasers. These devices thwart attempts to tempt the trio to sin by citing relevant pieces of scripture. The entire segment is very tongue-in-cheek, but absolutely entertaining.

The entire episode was released for free by Focus on the Family as a part of an episode of "The Official Adventures in Odyssey Podcast".

[Link to The Podcast Episode](https://www.oneplace.com/ministries/the-official-adventures-in-odyssey-podcast/player/june-13-2007-free-adventures-in-odyssey-episode-hidden-in-my-heart-798810.html)

The "Sky Trip" portion of the episode starts at 12:28, if you want to skip directly to it.

## License

scripture_phaser is licensed under the BSD 3-Clause License. See LICENSE file or the [Open Source Initiative](https://opensource.org/license/bsd-3-clause/) for the full text of the license.
